(use-modules (aiscm int) (aiscm rgb) (aiscm complex))
(<< 3 2)
;12
(% 1234 100)
;34
(| 240 15)
;255
(+ (rgb 2 3 5) 1)
;(rgb 3 4 6)
(== (rgb 2 2 2) 2)
;#t
